function [A,wout,wlim]=EAP(S,Hs,Tp,p,n,wmin,wmax,gamma)
%Calculate the amplitudes and frequency from given spectrum by EAP
%S=given spectrum: JONSWAP or PM
%Hs=significant weight
%T1=mean period
%n=number of component of EAP
%wmin=the smallest frequency for spectrum, default = 0.18
%wmax=the highest frequency for spectrum,default=sqrt(2*g/Hs)
%wout=frequency of harmonic waves (mean of two neighbouring wlimit
%A=amplitude
%wlim=two frequencies that limiting wout (at lef and right side)

%declaration of default value
if ~exist('n','var'); n=30; end
if ~exist('p','var'); p='no'; end
if ~exist('wmin','var'); wmin=0.18; end
if ~exist('wmax','var'); wmax=sqrt(2*9.812/Hs); end
if ~exist('gamma','var'); gamma=42.2*((2*pi*Hs/(9.812*(Tp^2)))^(6/7)); end

switch S
    case 'JONSWAP'
        [Si,w,m0]=JONSWAP(Hs,Tp,wmin,wmax,2*pi/50000,gamma);
    case 'PM'
        [Si,w,m0]=PM(Hs,Tp,wmin,wmax,2*pi/50000);
end

m=m0/n;%equal area
dw=w(2)-w(1);
ms=cumsum(Si*dw);%cummulative area
wmin=min(w);
wout=zeros(1,n);
wlim=[wmin zeros(1,n)];
for i=1:n
    j=find(ms>i*m,1)-1;
    if i==n
        j=length(w);
    end
    wout(i)=(wmin+w(j))/2;
    wmin=w(j);
    wlim(i+1)=wmin;
end

A=sqrt(2*m)*ones(1,length(wout));

%plot
if strcmp(p,'yes')
   plot(w,Si); hold all
   
   switch S
    case 'JONSWAP'
        Sii=JONSWAP(Hs,Tp,wout);
    case 'PM'
        Sii=PM(Hs,Tp,wout);
   end

   for ix=1:length(Sii)
       plot([wlim(ix) wlim(ix) wlim(ix+1) wlim(ix+1)],...
           [0 Sii(ix) Sii(ix) 0],'r');
       hold all
   end
   title('EAP')
   xlabel('w (rad/s)')
   ylabel('S (m2s)')
end
