function [A,wout,wout2]=EAPP(S,Hs,Tp,p,wn,n,dr,wmin,wmax,gamma)
%Calculate the amplitudes and frequency from given spectrum by EAP
%S=given spectrum: JONSWAP or PM
%Hs=significant weight
%T1=mean period
%n=number of component of EAP
%wmin=the smallest frequency for spectrum, default = 0.18
%wmax=the highest frequency for spectrum,default=sqrt(2*g/Hs)
%wout=frequency of harmonic waves
%A=amplitude
%dr=density

%declaration of default value
if ~exist('n','var'); n=30; end
if ~exist('p','var'); p='no'; end
if ~exist('d','var'); dr=0; end
if ~exist('wmin','var'); wmin=0.18; end
if ~exist('wmax','var'); wmax=sqrt(2*9.812/Hs); end
if ~exist('gamma','var'); gamma=42.2*((2*pi*Hs/(9.812*(Tp^2)))^(6/7)); end

np=round(n*dr);%peaked component number
ne=n-np;%eap component number
[~,w,wlim]=EAP(S,Hs,Tp,'no',ne,wmin,wmax,gamma);

j=find(wlim>wn,1)-1;
F=length(wlim);
if j<1
    disp('wn out of range');
    return
elseif j==1
    imin=j;%index of minimum freuency at peaked frequency range
    imax=j+2;%index of maximum freuency at peaked frequency range
elseif j==2
    imin=j-1;
    imax=j+3;
elseif j<F-2
    imin=j-2;
    imax=j+3;
elseif j<F-1
    imin=j-2;
    imax=j+2;
elseif j<F
    imin=j-1;
    imax=j+1;
else
    disp('wn out of range');
    return
end
nlim=np+(imax-imin)+1;%number of limiting point

%distribute component in left and right side
if abs(wn-wlim(imin))>abs(wn-wlim(imax))
    nleft=floor((nlim+1)/2);%number of limiting frequency in right side
    nright=nlim-nleft;%number of limiting frequency in left side
else
    nright=floor((nlim+1)/2);%number of limiting frequency in right side
    nleft=nlim-nright;%number of limiting frequency in left side
end

wleft=zeros(1,nleft);
wright=zeros(1,nright);

dwl=0;dwr=0;
for il=nleft:-1:1
    dwl=dwl+(wn-wlim(imin))*(nleft-(il-1))/(nleft*((nleft+1)/2));
    wleft(il)=wn-dwl;
end

for ir=nright:-1:1
    dwr=dwr+(wlim(imax)-wn)*(nright-(ir-1))/(nright*((nright+1)/2));
    wright(nright-ir+1)=wn+dwr;
end

wout1=[wleft wright];%combining the limiting frequency

%averaging frequency from limiting frequency
woutm=(wout1(2:end)+wout1(1:end-1))/2;
wout2=[wlim(1:imin-1) wout1 wlim(imax+1:end)];%all limiting frequency
wout=[w(1:imin-1) woutm w(imax:end)];

switch S
    case 'JONSWAP'
        Si=JONSWAP(Hs,Tp,wout);
    case 'PM'
        Si=PM(Hs,Tp,wout);
end

wmean=(wout(2:end)-wout(1:end-1))/2;
dw=[(wout(2)-wout(1)) wmean(1:end-1)+wmean(2:end) wout(end)-wout(end-1)];
A=sqrt(2*Si.*dw);

%plot
if strcmp(p,'yes')
    switch S
    case 'JONSWAP'
        [Sii,Wi]=JONSWAP(Hs,Tp);
    case 'PM'
        [Sii,Wi]=PM(Hs,Tp);
    end

   plot(Wi,Sii); hold all
   
   for ix=1:length(Si)
       if ix>imin-1 && ix<imax
       plot([wout2(ix) wout2(ix) wout2(ix+1) wout2(ix+1)],...
           [0 Si(ix) Si(ix) 0],'g');
       else
           plot([wout2(ix) wout2(ix) wout2(ix+1) wout2(ix+1)],...
           [0 Si(ix) Si(ix) 0],'r');
       end
       hold all
   end
   title('EAPP')
   xlabel('w (rad/s)')
   ylabel('S (m2s)')
end
