function [A,wout,wlim]=FFT(S,Hs,Tp,p,dw,wmin,wmax,gamma)
%Calculate the amplitudes and frequency from choosen spectrum by FFT
%S=given spectrum: JONSWAP or PM
%Hs=significant weight
%T1=mean period
%p=plot or not-->'yes' or 'no'
%dw=frequency interval, default = 2*pi/10800 (refer to 3-hour simulation)
%wmin=the smallest frequency for spectrum, default = 0.18
%wmax=the highest frequency for spectrum,default=sqrt(2*g/Hs)
%wout=frequency of harmonic waves
%A=amplitude

%declaration of default value
if ~exist('dw','var'); dw=2*pi/10800; end
if ~exist('p','var'); p='no'; end
if ~exist('wmin','var'); wmin=0.18; end
if ~exist('wmax','var'); wmax=sqrt(2*9.812/Hs); end
if ~exist('gamma','var'); gamma=42.2*((2*pi*Hs/(9.812*(Tp^2)))^(6/7)); end

switch S
    case 'JONSWAP'
        [Si,wout]=JONSWAP(Hs,Tp,wmin,wmax,dw,gamma);
    case 'PM'
        [Si,wout]=PM(Hs,Tp,wmin,wmax,dw);
end
A=sqrt(2*Si*dw);
wlim=[wout(1)-0.5*dw wout+0.5*dw];

%plot
if strcmp(p,'yes')
    switch S
    case 'JONSWAP'
        [Sii,wii]=JONSWAP(Hs,Tp,wmin,wmax,2*pi/300,gamma);
    case 'PM'
        [Sii,wii]=PM(Hs,Tp,wmin,wmax,2*pi/300);
    end
    plot(wii,Sii);
    hold all

   for ix=1:length(Si)
       plot([wlim(ix) wlim(ix) wlim(ix+1) wlim(ix+1)],...
           [0 Si(ix) Si(ix) 0],'r')
       hold all
   end
   title('FFT')
   xlabel('w (rad/s)')
   ylabel('S (m2s)')
end