function [n,m,h,C,FHex,FCex,P]=HC3H(q,depth,c,d,lambda,alpha,beta)
%calculating the 3 hour extreme wave height and wave crest
%INPUT:
%q=annual probability
%depth=the depth of the sea for calculating crest distribution
%c=parameter used for condition function of the log mean of the spectral peak
    %period
%d=parameter used for condition function of the log variance of the spectral peak
    %period
%lambda = location parameter of 3-parameter weibull distribution
%alpha = scale parameter of 3-parameter weibull distribution
%beta = shape parameter of 3-parameter weibull distribution

%OUTPUT:
%n=number of iteration done for calculating h (if =50, calculation not
    %reliable)
%m==number of iteration done for calculating C (if =50, calculation not
    %reliable)
%h=wave height
%FHex=the CDF for wave height result
%C= wave crest
%FCex=the CDF for wave crest result

Fh=1-(q/2920);%calculating CDF from annual probability
Fc=1-(q/2920);%calculating CDF from annual probability
 
dHs=1;%interval of Hs
dTp=1;%interval of Tp

P=0;
for Hsin=lambda+dHs:dHs:25
    Tpin=0.00001+dTp:dTp:35;
    Tpmean=c(1)+(c(2)*(Hsin^c(3)));
    Tpvar=(d(3))+(d(1)*exp(-d(2)*Hsin));
    fTp=normcdf(log(Tpin),Tpmean,sqrt(Tpvar))-...
        normcdf(log(Tpin-dTp),Tpmean,sqrt(Tpvar));
    fHs=(1-exp(-(((Hsin-lambda)/alpha).^beta)))-...
        (1-exp(-(((Hsin-dHs-lambda)/alpha).^beta)));
    P=P+sum(fHs.*fTp);
end

%iteration to get q-probability value for wave height
h1=1;
h2=100;
FHex=0;
n=0;
while abs(FHex-Fh)>1e-11 && n<50
%for h=1:50;
FHex=0;
FHex1=0;
h=(h1+h2)/2;
n=n+1;
for Hsin=lambda+dHs:dHs:25
    Tpin=0.00001+dTp:dTp:35;
    Tpmean=c(1)+(c(2)*(Hsin^c(3)));
    Tpvar=(d(3))+(d(1)*exp(-d(2)*Hsin));
    fTp=normcdf(log(Tpin),Tpmean,sqrt(Tpvar))-...
        normcdf(log(Tpin-dTp),Tpmean,sqrt(Tpvar));
    fHs=(1-exp(-(((Hsin-lambda)/alpha).^beta)))-...
        (1-exp(-(((Hsin-dHs-lambda)/alpha).^beta)));
    T1=0.78*Tpin;
    FH=(1-exp(-2.263*((h/Hsin)^2.126))).^(3*60*60./T1);
    FH1=(1-exp(-2.263*((h1/Hsin)^2.126))).^(3*60*60./T1);
    FHex=FHex+sum(FH*fHs.*fTp/P);
    FHex1=FHex1+sum(FH1*fHs.*fTp/P);
end
    F(n)=FHex;
    h10(n)=h;
    
    if (FHex-Fh)*(FHex1-Fh)<0;
        h2=h;
    else
        h1=h;
    end
end
%figure(q*10000+2)
%plot(log(h10),log(-log(1-F)),log([0.0001 50]),log(-log(1-[Fh Fh])))
%hold all;plot(log([0.0001 50]),log(-log(1-[1-(q/29200) 1-(q/29200)])))
%hold all;plot(log([0.0001 50]),log(-log(1-[1-(q/2920000) 1-(q/2920000)])))
%axis([0 inf 0 5])
%xlabel('ln(H)');
%ylabel('ln(-ln(1-F))');
%legend('Data','q=0.1','q=0.01','q=0.0001','Location','Best');

%iteration to get q-probability value for wave crest
C1=1;
C2=50;
FCex=0;
m=0;
while abs(FCex-Fc)>1e-8 && m<50
%for C=1:50;    
FCex=0;
FCex1=0;
C=(C1+C2)/2;
m=m+1;
for Hsin=lambda+dHs:dHs:25
    Tpin=0.00001+dTp:dTp:35;
    Tpmean=c(1)+(c(2)*(Hsin^c(3)));
    Tpvar=(d(3))+(d(1)*exp(-d(2)*Hsin));
    fTp=normcdf(log(Tpin),Tpmean,sqrt(Tpvar))-...
        normcdf(log(Tpin-dTp),Tpmean,sqrt(Tpvar));
    fHs=(1-exp(-(((Hsin-lambda)/alpha).^beta)))-...
        (1-exp(-(((Hsin-dHs-lambda)/alpha).^beta)));
    T1=0.78*Tpin;
    w1=2*pi./T1;
    k1=wavenum(w1,depth);
    Ur=Hsin./((k1.^2)*(depth^3));
    S1=k1.*Hsin./(2*pi);
    BETA=2-(2.1597*S1)+(0.0968*(Ur.^2));
    ALPHA=0.3536+(0.2892*S1)+(0.1060*Ur);
    FC=(1-exp(-((C./(ALPHA*Hsin)).^BETA))).^(3*60*60./T1);
    FC1=(1-exp(-((C1./(ALPHA*Hsin)).^BETA))).^(3*60*60./T1);
    FCex=FCex+sum(FC.*fHs.*fTp/P);
    FCex1=FCex1+sum(FC1.*fHs.*fTp/P);
end
    FT(m)=FCex;
    c10(m)=C;
    
    if (FCex-Fh)*(FCex1-Fh)<0;
        C2=C;
    else
        C1=C;
    end
end
%figure(q*10000+3)
%plot(log(c10),log(-log(1-FT)),log([0.0001 50]),log(-log(1-[Fc Fc])))
%hold all;plot(log([0.0001 50]),log(-log(1-[1-(q/29200) 1-(q/29200)])))
%hold all;plot(log([0.0001 50]),log(-log(1-[1-(q/2920000) 1-(q/2920000)])))
%axis([0 inf 0 5])
%xlabel('ln(\xi)');
%ylabel('ln(-ln(1-F))');
%legend('Data','q=0.1','q=0.01','q=0.0001','Location','Best');