function [n,m,h,C,FHex,FCex,V,P,VP]=HCin(q,depth,c,d,lambda,alpha,beta)
%calculating the individual extreme wave height and wave crest
%INPUT:
%q=annual probability
%depth=the depth of the sea for calculating crest distribution
%c=parameter used for condition function of the log mean of the spectral peak
    %period
%d=parameter used for condition function of the log variance of the spectral peak
    %period
%lambda = location parameter of 3-parameter weibull distribution
%alpha = scale parameter of 3-parameter weibull distribution
%beta = shape parameter of 3-parameter weibull distribution

%OUTPUT:
%n=number of iteration done for calculating h (if =50, calculation not
    %reliable)
%m==number of iteration done for calculating C (if =50, calculation not
    %reliable)
%h=wave height
%FHex=the CDF for wave height result
%C= wave crest
%FCex=the CDF for wave crest result
dHs=1;%interval of Hs
dTp=1;%interval of Tp

%for interval=[1 0.5 0.1]
%dHs=interval;
%dTp=interval;

%calculating mean zero crossing frequency
V=0;
for Hsin=lambda+dHs:dHs:50;
    Tpin=0.00001+dTp:dTp:50;
    Tpmean=c(1)+(c(2)*(Hsin^c(3)));
    Tpvar=(d(3))+(d(1)*exp(-d(2)*Hsin));
    fTp=normcdf(log(Tpin),Tpmean,sqrt(Tpvar))-...
        normcdf(log(Tpin-dTp),Tpmean,sqrt(Tpvar));
    fHs=(1-exp(-(((Hsin-lambda)/alpha).^beta)))-...
        (1-exp(-(((Hsin-dHs-lambda)/alpha).^beta)));
    T1=0.78*Tpin;
    V=V+sum((1./T1)*fHs.*fTp);
end

P=0;
VP=0;
for Hsin=lambda+dHs:dHs:50;
    Tpin=0.00001+dTp:dTp:50;
    Tpmean=c(1)+(c(2)*(Hsin^c(3)));
    Tpvar=(d(3))+(d(1)*exp(-d(2)*Hsin));
    fTp=normcdf(log(Tpin),Tpmean,sqrt(Tpvar))-...
        normcdf(log(Tpin-dTp),Tpmean,sqrt(Tpvar));
    fHs=(1-exp(-(((Hsin-lambda)/alpha).^beta)))-...
        (1-exp(-(((Hsin-dHs-lambda)/alpha).^beta)));
    P=P+sum(fHs*fTp);
    VP=VP+sum((1./T1)*fHs.*fTp/V);
end

%calculating CDF from annual probability and mean zero crossing frequency 
Fh=1-(q/(365*24*60*60*V));
Fc=1-(q/(365*24*60*60*V));

%iteration to get q-probability value for wave height
h1=1;
h2=100;
FHex=0;
n=0;
while abs(FHex-Fh)>1e-11 && n<50
%for h=2:50;
FHex=0;
FHex1=0;
h=h1+((h2-h1)/2);
n=n+1;
for Hsin=lambda+dHs:dHs:50
    Tpin=0.00001+dTp:dTp:50;
    Tpmean=c(1)+(c(2)*(Hsin^c(3)));
    Tpvar=(d(3))+(d(1)*exp(-d(2)*Hsin));
    fTp=normcdf(log(Tpin),Tpmean,sqrt(Tpvar))-...
        normcdf(log(Tpin-dTp),Tpmean,sqrt(Tpvar));
    fHs=(1-exp(-(((Hsin-lambda)/alpha).^beta)))-...
        (1-exp(-(((Hsin-dHs-lambda)/alpha).^beta)));
    T1=0.78*Tpin;
    FH=(1-exp(-2.263*((h/Hsin)^2.126))).*((1./T1)/V);
    FH1=(1-exp(-2.263*((h1/Hsin)^2.126))).*((1./T1)/V);
    FHex=FHex+sum(FH*fHs.*fTp/P);
    FHex1=FHex1+sum(FH1*fHs.*fTp/P);
end
    F(n)=FHex;
    h10(n)=h;
   
    if (FHex-Fh)*(FHex1-Fh)<0;
        h2=h;
    else
        h1=h;
    end
end
%figure(q*10000)
%plot(log(h10),log(-log(1-F)),log([0.0001 50]),log(-log(1-[Fh Fh])))
%hold all;plot(log([0.0001 50]),log(-log(1-[1-(0.01/(365*24*60*60*V)) 1-(0.01/(365*24*60*60*V))])))
%hold all;plot(log([0.0001 50]),log(-log(1-[1-(0.0001/(365*24*60*60*V)) 1-(0.0001/(365*24*60*60*V))])))
%axis([0 inf 0 5])
%xlabel('ln(H)');
%ylabel('ln(-ln(1-F))');
%legend('Data','q=0.1','q=0.01','q=0.0001','Location','Best');

%iteration to get q-probability value for wave crest
C1=1;
C2=100;
FCex=0;
m=0;
while abs(FCex-Fc)>1e-11 && m<50
%for C=0.1:1:30;
%C=21;
%for interval=0.1:0.1:5
%dHs=interval;
%dTp=interval;
FCex=0;
FCex1=0;
C=C1+((C2-C1)/2);
m=m+1;
for Hsin=lambda+dHs:dHs:50
    %m=m+1;
    Tpin=0.00001+dTp:dTp:50;
    Tpmean=c(1)+(c(2)*(Hsin^c(3)));
    Tpvar=(d(3))+(d(1)*exp(-d(2)*Hsin));
    fTp=normcdf(log(Tpin),Tpmean,sqrt(Tpvar))-...
        normcdf(log(Tpin-dTp),Tpmean,sqrt(Tpvar));
    fHs=(1-exp(-(((Hsin-lambda)/alpha).^beta)))-...
        (1-exp(-(((Hsin-dHs-lambda)/alpha).^beta)));
    T1=0.78*Tpin;
    w1=2*pi./T1;
    k1=wavenum(w1,depth);
    Ur=Hsin./((k1.^2)*(depth^3));
    S1=k1*Hsin/(2*pi);
    BETA=2-(2.1597*S1)+(0.0968*(Ur.^2));
    ALPHA=0.3536+(0.2892*S1)+(0.1060*Ur);
    FC=(1-exp(-((C./(ALPHA*Hsin)).^BETA))).*((1./T1)/V);
    FC1=(1-exp(-((C1./(ALPHA*Hsin)).^BETA))).*((1./T1)/V);
    FCex=FCex+sum(FC*fHs.*fTp/P);
    FCex1=FCex1+sum(FC1.*fHs.*fTp/P);
    
    %FCC(m,:)=FC*fHs.*fTp/P;
end
    FT(m)=FCex;
    c10(m)=C;
    
    if (FCex-Fh)*(FCex1-Fh)<0;
        C2=C;
    else
        C1=C;
    end
end

%figure(q*10000+1)
%plot(0.1:0.1:5,FT,'.-');
%xlabel('class interval');ylabel('F')
%grid on

%[X,Y]=meshgrid(0.00001+dTp:dTp:50,lambda+dHs:dHs:20);
%surf(X,Y,FCC);
%xlabel('Tp');ylabel('Hs');zlabel('Fc x fHs x fTp');

%plot(log(c10),log(-log(1-FT)));hold all
%end
%plot(log([0.0001 50]),log(-log(1-[Fc Fc])));
%hold all;plot(log([0.0001 50]),log(-log(1-[1-(0.01/(365*24*60*60*V)) 1-(0.01/(365*24*60*60*V))])))
%hold all;plot(log([0.0001 50]),log(-log(1-[1-(0.0001/(365*24*60*60*V)) 1-(0.0001/(365*24*60*60*V))])))
%axis([-inf inf -inf 5])
%xlabel('ln(\xi)');
%ylabel('ln(-ln(1-F))');
%legend('Data','q=0.1','q=0.01','q=0.0001','Location','Best');
%legend('Data,Interval = 1','Data,Interval = 0.5','Data,Interval = 0.1',...
%    'q=0.1','q=0.01','q=0.0001','Location','Best');

%figure(q*10000+2)
%plot(c10,FT)
%hold all;plot([0.0001 50],[Fc Fc])
%hold all;plot([0.0001 50],[1-(0.01/(365*24*60*60*V)) 1-(0.01/(365*24*60*60*V))])
%hold all;plot([0.0001 50],[1-(0.0001/(365*24*60*60*V)) 1-(0.0001/(365*24*60*60*V))])
%axis([0 inf 0 inf])
%xlabel('\xi');
%ylabel('F');
%legend('Data','q=0.1','q=0.01','q=0.0001','Location','Best');