function [S,w,m0,m1,m2,m3,m4]=JONSWAP(Hs,Tp,wmin,wmax,dw,gamma)
%This function is calculated the JONSWAP spectrum and its moments
%Hs=significant wave height
%Tp=spectral peak period
%n=number of wave, default = 2*pi/10800 (refer to 3 hour simulation)
%wmin=the smallest frequency for spectrum, 
    %default = 2*pi/10800 (refer to 3 hour simulation)
%wmax=the highest frequency for spectrum, default=sqrt(2*g/Hs)
%wmin also could be a set of input frequencies, then wmax and n is
    %neglected
%gamma=peak enhancement factor=1~7, default=442.2*((2*pi*Hs/(g*(Tp^2)))^(6/7)) (average)
%S=JONSWAP spectrum
%w=frequency of each S value
%m0,m1,m2,m3,m4=zeroth,first,second,third and fourth moment of spectrum
    
g=9.812;%gravity acceleration
wp=2*pi/Tp;
    
%declaration of default value
if ~exist('gamma','var'); gamma=42.2*((2*pi*Hs/(g*(Tp^2)))^(6/7)); end
if ~exist('dw','var'); dw=2*pi/10800; end
if ~exist('wmin','var'); wmin=0.00001; end
if ~exist('wmax','var'); wmax=sqrt(2*g/Hs); end

%option if w already given or not
switch length(wmin)
    case 1
        w=wmin:dw:wmax;
    otherwise
        w=wmin;
        wmean=(w(2:end)-w(1:end-1))/2;
        dw=[(w(2)-w(1)) wmean(1:end-1)+wmean(2:end) w(end)-w(end-1)];
end

%calculation
sigma=zeros(1,length(w));
for i=1:length(w)
    if w(i)<=wp
        sigma(i)=0.07;
    else
        sigma(i)=0.09;
    end
end
S=0.05*(Hs^2)*Tp*(1-(0.287*log(gamma)))*((w/wp).^-5).*...
    exp(-1.25*((w./wp).^-4)).*(gamma.^(exp(-0.5*(((w-wp)./(sigma*wp)).^2))));
S(isnan(S))=0;
m0=sum(S.*dw);
m1=sum(S.*w.*dw);
m2=sum(S.*w.^2.*dw);
m3=sum(S.*w.^3.*dw);
m4=sum(S.*w.^4.*dw);