clc
close all
clearvars

%==========================================================================
%INPUT
%==========================================================================
Hs=13.0;
Tp=15.9;
dt=0.5;
t=0:dt:1200;
x=-50:5:50;
L=115;
d=100;
D1=1;%Diameter of pipe-->drag dominated
D2=8;%Diameter of pipe-->mass dominated
th=0.01;%Wall Thickness (m)
spe='JONSWAP';%choosen spectrum
%n=1000;%number of harmonic component
dr=0.15;%density for EAPP method
wn=0;%natural frequency of structure for EAPP purposes
apfmethod=2;%method choosing Amplitude, Frequency and Phase
    %1.Random Phase
    %2.Random amplitude and phase
    %3.Random wave frequency and phase
    %4.Combination
harmonic=1;%method of calculating harmonic
    %1.FFT
    %2.EAP
    %3.EAPP
p='no';%plot for spectrum
%nz=70;%number of z-coordinate point from surface to depth
El=150;%number of element for FEM model
animation='no';% make animation
sk=10;%skip time to avoid deviation in wheeler when calculating dynamic response
wmin=2*pi/(t(end)-t(1));
%wmax=2*pi/(2*dt);%Full Analysis
wmax=sqrt(2*9.812/Hs);%stansberg cut-off frequency
dw=2*pi/(t(end)-t(1));%For FFT1 AND 2
%n=round((wmax-wmin)/dw);
%n=220;
%dw=wmax/n;%for FFT3,4 and EAP
%wmin=dw;%for FFFT,4 and EAP

stopwatch=tic;
%==========================================================================
%SPECTRUM
%==========================================================================
wp=2*pi/Tp;
switch spe
    case 'PM'
        [~,~,m0,m1,m2,m3,m4]=PM(Hs,Tp,wmin,2*pi/(2*dt),2*pi/10800);
    case'JONSWAP'
        [~,~,m0,m1,m2,m3,m4]=JONSWAP(Hs,Tp,wmin,2*pi/(2*dt),2*pi/10800);
end
%==========================================================================
%HARMONIC COMPONENT
%==========================================================================
switch harmonic
    case 1
        [A1,w1,wlim]=FFT(spe,Hs,Tp,p,dw,wmin,wmax);
    case 2
        [A1,w1,wlim]=EAP(spe,Hs,Tp,p,n,wmin,wmax);
    case 3
        [A1,w1,wlim]=EAPP(spe,Hs,Tp,p,wn,n,dr,wmin,wmax);
end

t=0:dt:1500;
%Preallocating memory for second order result
total4=zeros(numel(x),numel(t));total5=total4;
nz=numel([-d -80 -70 -60:5:-30 -29:30]);
ux4=zeros(numel(x),numel(t),nz);uz4=ux4;ax4=ux4;az4=ux4;
ux5=ux4;uz5=ux4;ax5=ux4;az5=ux4;

NSIMULATE=700;
for SIMULATE=641:NSIMULATE;
disp(['SIMULATION = ',num2str(SIMULATE)]);
disp('===================================================================')
%==========================================================================
%AMPLITUDE AND FREQUENCY
%==========================================================================
%choosing amplitude, phase and frequency
tic
[A,w,phase]=apf(A1,w1,wlim,apfmethod);
durationapf=toc;
disp(['Duration of amplitude, phase and frequency calculation = ',...
    num2str(durationapf),' seconds']);
save(['APF-',num2str(SIMULATE),'.mat'],'A','w','phase');

%==========================================================================
%IRREGULAR LINEAR WAVE ANALYSIS
%==========================================================================
tic
surface=linsurface(A,w,phase,x,t,d);
duration1=toc;
disp(['Duration of first order surface calculation = ',...
    num2str(duration1),' seconds']);

%tic
%[ux1,uz1,ax1,az1,z1,~]=...
%    linkinematic(A,w,phase,surface,x,t,nz,d,1);%wheeler
%duration2=toc;
%disp(['Duration of first order kinematic wheeler calculation = ',...
%    num2str(duration2),' seconds']);

%tic
%[ux2,uz2,ax2,az2,z2,~]=...
%    linkinematic(A,w,phase,surface,x,t,nz,d,2);%stansberg
%duration3=toc;
%disp(['Duration of first order kinematic stansberg calculation = ',...
%    num2str(duration3),' seconds']);

%tic
%[ux3,uz3,ax3,az3,z3,~]=...
%    linkinematic(A,w,phase,surface,x,t,nz,d,3);%Constant
%duration4=toc;
%disp(['Duration of first order kinematic constant calculation = ',...
%    num2str(duration4),' seconds'])

%==========================================================================
%IRREGULAR NON-LINEAR WAVE ANALYSIS
%==========================================================================
%tic
dx=10;
%for XN=dx:dx:numel(x)
%    III=1+(XN-dx):XN;
%    if XN==numel(x)-1
%        III=1+(XN-dx):XN+1;
%    end
%[total4(III,:),~,ux4(III,:,:),uz4(III,:,:),ax4(III,:,:),...
%    az4(III,:,:),z4,~,~,~]...
%    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t,1,wp,1,0,...
%    surface(III,:));%wheeler
%end
%duration5=toc;
%disp(['Duration of second order wheeler calculation = ',...
%    num2str(duration5),' seconds']);

tic
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==numel(x)-1
        III=1+(XN-dx):XN+1;
    end
[total5(III,:),~,ux5(III,:,:),uz5(III,:,:),ax5(III,:,:),...
    az5(III,:,:),z5,~,~,~]...
    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t,2,wp,1,1,...
    surface(III,:));%stansberg
end
duration6=toc;
disp(['Duration of second order stansberg calculation = ',...
    num2str(duration6),' seconds']);

%==========================================================================
%TOTAL DURATION
%==========================================================================
duration7=toc(stopwatch);
disp(['Total duration of program = ',...
    num2str(duration7),' seconds']);

%==========================================================================
%CREATING GRID WAVE FILE
%==========================================================================
%parfor WR=1:5
%    switch WR
%        case 1
%tic
%gridwave(['wavelinwheeler-',num2str(SIMULATE)],x,-50:100:50,z1,t,surface,...
%    ux1,zeros(size(ux1)),uz1,...
%    ax1,zeros(size(ax1)),az1)
%duration8=toc;
%disp(['Duration of writing first order wheeler gridfile = ',...
%    num2str(duration8),' seconds']);

%        case 2
%tic
%gridwave(['wavelin-',num2str(SIMULATE)],x,-50:100:50,z2,t,surface,...
%    ux2,zeros(size(ux2)),uz2,...
%    ax2,zeros(size(ax2)),az2)
%duration9=toc;
%disp(['Duration of writing first order stansberg gridfile = ',...
%    num2str(duration9),' seconds']);

%        case 3
%tic
%gridwave(['wavelinconst-',num2str(SIMULATE)],x,-50:100:50,z3,t,surface,...
%    ux3,zeros(size(ux3)),uz3,...
%    ax3,zeros(size(ax3)),az3)
%duration10=toc;
%disp(['Duration of writing first order stansberg gridfile = ',...
%    num2str(duration10),' seconds']);

%        case 4
%tic
%gridwave(['wavesecwheeler-',num2str(SIMULATE)],x,-50:100:50,z4,t,total4,...
%    ux4,zeros(size(ux4)),uz4,...
%    ax4,zeros(size(ax4)),az4)
%duration11=toc;
%disp(['Duration of writing linear gridfile = ',...
%    num2str(duration11),' seconds']);

%        case 5
tic
gridwave(['wavesec-',num2str(SIMULATE)],x,-50:100:50,z5,t,total5,...
    ux5,zeros(size(ux5)),uz5,...
    ax5,zeros(size(ax5)),az5)
duration12=toc;
disp(['Duration of writing first order stansberg gridfile = ',...
    num2str(duration12),' seconds']);
%    end
%end
disp('===================================================================')
end