clc
close all
clearvars

%==========================================================================
%INPUT
%==========================================================================
Hs=13.0;
Tp=15.9;
dt=0.5;
t=0:dt:1200;
x=-50:5:50;
L=115;
d=100;
D1=1;%Diameter of pipe-->drag dominated
D2=8;%Diameter of pipe-->mass dominated
th=0.01;%Wall Thickness (m)
spe='JONSWAP';%choosen spectrum
%n=1000;%number of harmonic component
dr=0.15;%density for EAPP method
wn=0;%natural frequency of structure for EAPP purposes
apfmethod=2;%method choosing Amplitude, Frequency and Phase
    %1.Random Phase
    %2.Random amplitude and phase
    %3.Random wave frequency and phase
    %4.Combination
harmonic=1;%method of calculating harmonic
    %1.FFT
    %2.EAP
    %3.EAPP
p='no';%plot for spectrum
nz=70;%number of z-coordinate point from surface to depth
El=150;%number of element for FEM model
animation='no';% make animation
sk=10;%skip time to avoid deviation in wheeler when calculating dynamic response
wmin=2*pi/(t(end)-t(1));
%wmax=2*pi/(2*dt);%Full Analysis
wmax=sqrt(2*9.812/Hs);%stansberg cut-off frequency
dw=2*pi/(t(end)-t(1));%For FFT1 AND 2
%n=round((wmax-wmin)/dw);
%n=220;
%dw=wmax/n;%for FFT3,4 and EAP
%wmin=dw;%for FFFT,4 and EAP

stopwatch=tic;
%==========================================================================
%SPECTRUM
%==========================================================================
wp=2*pi/Tp;
switch spe
    case 'PM'
        [~,~,m0,m1,m2,m3,m4]=PM(Hs,Tp,wmin,2*pi/(2*dt),2*pi/10800);
    case'JONSWAP'
        [~,~,m0,m1,m2,m3,m4]=JONSWAP(Hs,Tp,wmin,2*pi/(2*dt),2*pi/10800);
end
%==========================================================================
%HARMONIC COMPONENT
%==========================================================================
switch harmonic
    case 1
        [A1,w1,wlim]=FFT(spe,Hs,Tp,p,dw,wmin,wmax);
    case 2
        [A1,w1,wlim]=EAP(spe,Hs,Tp,p,n,wmin,wmax);
    case 3
        [A1,w1,wlim]=EAPP(spe,Hs,Tp,p,wn,n,dr,wmin,wmax);
end


%Preallocating memory for second order result
total=zeros(numel(x),numel(t));surface2=total;sur2plus=total;sur2min=total;
total4=total;surface24=total;
ux2=zeros(numel(x),numel(t),50);uz2=ux2;ax2=ux2;az2=ux2;pot2=ux2;
ux4=ux2;uz4=ux2;ax4=ux2;az4=ux2;pot4=ux2;
ux5=ux2;uz5=ux2;ax5=ux2;az5=ux2;

%==========================================================================
%AMPLITUDE AND FREQUENCY
%==========================================================================
%choosing amplitude, phase and frequency
tic
[A,w,phase]=apf(A1,w1,wlim,apfmethod);
durationapf=toc;
disp(['Duration of amplitude, phase and frequency calculation = ',...
    num2str(durationapf),' seconds']);

%% COMPLETE SIMULATION
%==========================================================================
%IRREGULAR LINEAR WAVE ANALYSIS
%==========================================================================
tic
surface=linsurface(A,w,phase,x,t,d);
duration1=toc;
disp(['Duration of first order surface calculation = ',...
    num2str(duration1),' seconds']);

tic
[ux1,uz1,ax1,az1,z1,p1,pot1]=...
    linkinematic(A,w,phase,surface,x,t,nz,d,1);%wheeler
duration2=toc;
disp(['Duration of first order kinematic wheeler calculation = ',...
    num2str(duration2),' seconds']);

tic
[ux3,uz3,ax3,az3,z3,p3,pot3]=...
    linkinematic(A,w,phase,surface,x,t,nz,d,2);%stansberg
duration3=toc;
disp(['Duration of first order kinematic stansberg calculation = ',...
    num2str(duration3),' seconds']);

%==========================================================================
%IRREGULAR NON-LINEAR WAVE ANALYSIS
%==========================================================================
tic
dx=10;
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==numel(x)-1
        III=1+(XN-dx):XN+1;
    end
[total(III,:),surface2(III,:),ux2(III,:,:),uz2(III,:,:),ax2(III,:,:),...
    az2(III,:,:),z2,pot2(III,:,:),sur2plus(III,:),...
    sur2min(III,:)]...
    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t,1,wp,1,0,...
    surface(III,:));%wheeler
end
duration4=toc;
disp(['Duration of second order wheeler calculation = ',...
    num2str(duration4),' seconds']);

tic
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==numel(x)-1
        III=1+(XN-dx):XN+1;
    end
[total4(III,:),surface24(III,:),ux4(III,:,:),uz4(III,:,:),ax4(III,:,:),...
    az4(III,:,:),z4,pot4(III,:,:),~,~]...
    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t,2,wp,1,1,...
    surface(III,:));%stansberg
end
duration5=toc;
disp(['Duration of second order stansberg calculation = ',...
    num2str(duration5),' seconds']);

%% BOTTOM LINEAR UPPER SECOND ORDER
%==========================================================================
%IRREGULAR LINEAR WAVE ANALYSIS
%==========================================================================
z=[-d -80 -70 -60:5:-30 -29:10];z5=zeros(size(z));
NI=0;
for lower=[-50 -40 -30 -25 -20 -15 -10 -5];%0 is mean surface value
    ux5=zeros(ux2);uz5=ux5;ax5=ux5;az5=ux5;
NI=NI+1;
tic
surfaceBU=linsurface(A,w,phase,x,t,d);

[~,INPL]=find(z<=lower);
[~,INPS]=find(z>=lower);

[ux5(:,:,INPL),uz5(:,:,INPL),...
    ax5(:,:,INPL),az5(:,:,INPL),z5(INPL),~,~]=...
    linkinematic(A,w,phase,lower(ones(size(surfaceBU))),x,t,nz,d,2);%stansberg

%==========================================================================
%IRREGULAR NON-LINEAR WAVE ANALYSIS
%==========================================================================
dx=10;
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==numel(x)-1
        III=1+(XN-dx):XN+1;
    end
[~,~,ux5(III,:,INPS),uz5(III,:,INPS),...
    ax5(III,:,INPS),az5(III,:,INPS),z5(INPS),~,~,~]...
    =secsurface(A,w,wlim,phase,d,lower,x(III),nz,t,2,wp,1,1,...
    surfaceBU(III,:));%stansberg
end
comdur(NI)=toc;
disp(['Duration of linear bottom nonlinear up stansberg calculation = ',...
    num2str(comdur(NI)),' seconds']);

tic
gridwave(['wavelin5-',num2str(lower)],x,-50:100:50,z5,t,total4,...
    ux5,zeros(size(ux5)),uz5,...
    ax5,zeros(size(ax5)),az5)
duration10=toc;
disp(['Duration of writing linear gridfile = ',...
    num2str(duration10),' seconds']);

end
%%
%==========================================================================
%CREATING GRID WAVE FILE
%==========================================================================
tic
gridwave('wavelin5-R',x,-50:100:50,z1,t,surface,...
    ux3,zeros(size(ux3)),uz3,...
    ax3,zeros(size(ax3)),az3)
duration10=toc;
disp(['Duration of writing linear gridfile = ',...
    num2str(duration10),' seconds']);

tic
gridwave('wavesecwheeler5-R',x,-50:100:50,z2,t,total,...
    ux2,zeros(size(ux2)),uz2,...
    ax2,zeros(size(ax2)),az2)
duration11=toc;
disp(['Duration of writing second order wheeler gridfile = ',...
    num2str(duration11),' seconds']);

tic
gridwave('wavesec5-R',x,-50:100:50,z4,t,total4,...
    ux4,zeros(size(ux4)),uz4,...
    ax4,zeros(size(ax4)),az4)
duration12=toc;
disp(['Duration of writing linear gridfile = ',...
    num2str(duration12),' seconds']);
disp('===================================================================')