clc
%close all
%clearvars

%==========================================================================
%INPUT
%==========================================================================
Hs=13.0;
Tp=15.9;
dt=0.5;
t=0:dt:1200;
x=-50:5:50;
L=115;
d=100;
D1=1;%Diameter of pipe-->drag dominated
D2=8;%Diameter of pipe-->mass dominated
th=0.01;%Wall Thickness (m)
spe='JONSWAP';%choosen spectrum
%n=1000;%number of harmonic component
dr=0.15;%density for EAPP method
wn=0;%natural frequency of structure for EAPP purposes
apfmethod=2;%method choosing Amplitude, Frequency and Phase
    %1.Random Phase
    %2.Random amplitude and phase
    %3.Random wave frequency and phase
    %4.Combination
harmonic=1;%method of calculating harmonic
    %1.FFT
    %2.EAP
    %3.EAPP
p='no';%plot for spectrum
nz=70;%number of z-coordinate point from surface to depth
El=150;%number of element for FEM model
animation='no';% make animation
sk=10;%skip time to avoid deviation in wheeler when calculating dynamic response
wmin=2*pi/(t(end)-t(1));
%wmax=2*pi/(2*dt);%Full Analysis
wmax=sqrt(2*9.812/Hs);%stansberg cut-off frequency
dw=2*pi/(t(end)-t(1));%For FFT1 AND 2
%n=round((wmax-wmin)/dw);
%n=220;
%dw=wmax/n;%for FFT3,4 and EAP
%wmin=dw;%for FFFT,4 and EAP

stopwatch=tic;
%==========================================================================
%SPECTRUM
%==========================================================================
wp=2*pi/Tp;
switch spe
    case 'PM'
        [~,~,m0,m1,m2,m3,m4]=PM(Hs,Tp,wmin,2*pi/(2*dt),2*pi/10800);
    case'JONSWAP'
        [~,~,m0,m1,m2,m3,m4]=JONSWAP(Hs,Tp,wmin,2*pi/(2*dt),2*pi/10800);
end
%==========================================================================
%HARMONIC COMPONENT
%==========================================================================
switch harmonic
    case 1
        [A1,w1,wlim]=FFT(spe,Hs,Tp,p,dw,wmin,wmax);
    case 2
        [A1,w1,wlim]=EAP(spe,Hs,Tp,p,n,wmin,wmax);
    case 3
        [A1,w1,wlim]=EAPP(spe,Hs,Tp,p,wn,n,dr,wmin,wmax);
end

%==========================================================================
%AMPLITUDE AND FREQUENCY
%==========================================================================
%choosing amplitude, phase and frequency
tic
[A,w,phase]=apf(A1,w1,wlim,apfmethod);
durationapf=toc;
disp(['Duration of amplitude, phase and frequency calculation = ',...
    num2str(durationapf),' seconds']);

%% COMPLETE SIMULATION
z{2}=-d:1:30;z{3}=-d:2:30;z{4}=[-d -80 -70 -60:5:-30 -29:30];
z{1}=-d:0.5:30;
t=0:dt:1500;
duration=zeros(2,4);
for INT=1:4
    Z=z{INT};
%Preallocating memory for second order result
total=zeros(numel(x),numel(t));surface2=total;sur2plus=total;sur2min=total;
ux2=zeros(numel(x),numel(t),numel(Z));uz2=ux2;ax2=ux2;az2=ux2;pot2=ux2;
%==========================================================================
%IRREGULAR LINEAR WAVE ANALYSIS
%==========================================================================
tic
surface=linsurface(A,w,phase,x,t,d);
[ux1,uz1,ax1,az1,z1,pot1]=...
    linkinematic(A,w,phase,surface,x,t,nz,d,1,Z);%wheeler
duration(1,INT)=toc;
disp(['Duration of first order kinematic wheeler calculation = ',...
    num2str(duration(1,INT)),' seconds']);

%==========================================================================
%IRREGULAR NON-LINEAR WAVE ANALYSIS
%==========================================================================
dx=min(10,numel(x));
XNN=dx:dx:numel(x);XNN=XNN(end);
parfor i=1
end
if dx==numel(x)
tic
[total,surface2,ux2,uz2,ax2,az2,z2,pot2,~,~]...
    =secsurface(A,w,wlim,phase,d,-d,x,nz,t,2,wp,1,0,...
    surface,Z);%stansberg
duration(2,INT)=toc;
disp(['Duration of second order stansberg calculation = ',...
    num2str(duration(2,INT)),' seconds']);
else
tic
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==XNN
        III=1+(XN-dx):numel(x);
    end
[total(III,:),surface2(III,:),ux2(III,:,:),uz2(III,:,:),ax2(III,:,:),...
    az2(III,:,:),z2,pot2(III,:,:),~,~]...
    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t,2,wp,1,1,...
    surface(III,:),Z);%stansberg
end
duration(2,INT)=toc;
disp(['Duration of second order stansberg calculation = ',...
    num2str(duration(2,INT)),' seconds']);
end

%%
%==========================================================================
%CREATING GRID WAVE FILE
%==========================================================================
tic
gridwave(['wavelin',num2str(INT)],x,-50:100:50,z1,t,surface,...
    ux1,zeros(size(ux1)),uz1,...
    ax1,zeros(size(ax1)),az1)
duration10=toc;
disp(['Duration of writing linear gridfile = ',...
    num2str(duration10),' seconds']);

tic
gridwave(['wavesec',num2str(INT)],x,-50:100:50,z2,t,total,...
    ux2,zeros(size(ux2)),uz2,...
    ax2,zeros(size(ax2)),az2)
duration12=toc;
disp(['Duration of writing second order gridfile = ',...
    num2str(duration12),' seconds']);
disp('===================================================================')
end
save DURATIONCOARSE.mat duration