clc
close all
clearvars

%==========================================================================
%INPUT
%==========================================================================
Hs=13.0;
Tp=15.9;
dt=0.5;
t=0:dt:1200;
x=-50:5:50;
L=115;
d=100;
D1=1;%Diameter of pipe-->drag dominated
D2=8;%Diameter of pipe-->mass dominated
th=0.01;%Wall Thickness (m)
spe='JONSWAP';%choosen spectrum
%n=1000;%number of harmonic component
dr=0.15;%density for EAPP method
wn=0;%natural frequency of structure for EAPP purposes
apfmethod=2;%method choosing Amplitude, Frequency and Phase
    %1.Random Phase
    %2.Random amplitude and phase
    %3.Random wave frequency and phase
    %4.Combination
harmonic=1;%method of calculating harmonic
    %1.FFT
    %2.EAP
    %3.EAPP
p='no';%plot for spectrum
nz=70;%number of z-coordinate point from surface to depth
El=150;%number of element for FEM model
animation='no';% make animation
sk=10;%skip time to avoid deviation in wheeler when calculating dynamic response
wmin=2*pi/(t(end)-t(1));
%wmax=2*pi/(2*dt);%Full Analysis
wmax=sqrt(2*9.812/Hs);%stansberg cut-off frequency
dw=2*pi/(t(end)-t(1));%For FFT1 AND 2
%n=round((wmax-wmin)/dw);
%n=220;
%dw=wmax/n;%for FFT3,4 and EAP
%wmin=dw;%for FFFT,4 and EAP

stopwatch=tic;
%==========================================================================
%SPECTRUM
%==========================================================================
wp=2*pi/Tp;
switch spe
    case 'PM'
        [~,~,m0,m1,m2,m3,m4]=PM(Hs,Tp,wmin,2*pi/(2*dt),2*pi/10800);
    case'JONSWAP'
        [~,~,m0,m1,m2,m3,m4]=JONSWAP(Hs,Tp,wmin,2*pi/(2*dt),2*pi/10800);
end
%==========================================================================
%HARMONIC COMPONENT
%==========================================================================
switch harmonic
    case 1
        [A1,w1,wlim]=FFT(spe,Hs,Tp,p,dw,wmin,wmax);
    case 2
        [A1,w1,wlim]=EAP(spe,Hs,Tp,p,n,wmin,wmax);
    case 3
        [A1,w1,wlim]=EAPP(spe,Hs,Tp,p,wn,n,dr,wmin,wmax);
end

t=0:dt:1500;
nz=numel([-d -80 -70 -60:5:-30 -29:30]);
%Preallocating memory for second order result
total=zeros(numel(x),numel(t));surface2=total;sur2plus=total;sur2min=total;
total4=total;surface24=total;total5=total;
ux2=zeros(numel(x),numel(t),nz);uz2=ux2;ax2=ux2;az2=ux2;pot2=ux2;
ux4=ux2;uz4=ux2;ax4=ux2;az4=ux2;pot4=ux2;
ux5=ux2;uz5=ux2;ax5=ux2;az5=ux2;

%% Iterate Amplitude, Frequency and Phase
MAXSPOOL=700;N=1;AFTER=200;
while true
%==========================================================================
%AMPLITUDE AND FREQUENCY
%==========================================================================
%choosing amplitude, phase and frequency
tic
[A,w,phase]=apf(A1,w1,wlim,apfmethod);
durationapf=toc;
disp(['Duration of amplitude, phase and frequency calculation = ',...
    num2str(durationapf),' seconds']);
%% CHECK IF THE CONDITION IS OKAY TO APPLY SPOOL TO EXTREME WITH VARIOUS
    %PARAMETER
tes=linsurface(A,w,phase,x,t,d);
[tesSP,~,~,~,~,~,~,~,~,~]...
    =secsurface(A,w,wlim,phase,d,-d,0,nz,t,2,wp,0,0,...
    tes(x==0,:));%cek surface
[T,SS,~,~]=statwave(t,tesSP);
[~,TS]=sort(SS,'descend');

if and(T(TS(1:N))>MAXSPOOL,T(TS(1:N))+AFTER<t(end))
    break
end
end
clear tes tesSP

%% COMPLETE SIMULATION
%==========================================================================
%IRREGULAR LINEAR WAVE ANALYSIS
%==========================================================================
tic
surface=linsurface(A,w,phase,x,t,d);
duration1=toc;
disp(['Duration of first order surface calculation = ',...
    num2str(duration1),' seconds']);

tic
[ux1,uz1,ax1,az1,z1,pot1]=...
    linkinematic(A,w,phase,surface,x,t,nz,d,1);%wheeler
duration2=toc;
disp(['Duration of first order kinematic wheeler calculation = ',...
    num2str(duration2),' seconds']);

tic
[ux3,uz3,ax3,az3,z3,pot3]=...
    linkinematic(A,w,phase,surface,x,t,nz,d,2);%stansberg
duration3=toc;
disp(['Duration of first order kinematic stansberg calculation = ',...
    num2str(duration3),' seconds']);

%==========================================================================
%IRREGULAR NON-LINEAR WAVE ANALYSIS
%==========================================================================
tic
dx=10;
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==numel(x)-1
        III=1+(XN-dx):XN+1;
    end
[total(III,:),surface2(III,:),ux2(III,:,:),uz2(III,:,:),ax2(III,:,:),...
    az2(III,:,:),z2,pot2(III,:,:),sur2plus(III,:),...
    sur2min(III,:)]...
    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t,1,wp,1,0,...
    surface(III,:));%wheeler
end
duration4=toc;
disp(['Duration of second order wheeler calculation = ',...
    num2str(duration4),' seconds']);

tic
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==numel(x)-1
        III=1+(XN-dx):XN+1;
    end
[total4(III,:),surface24(III,:),ux4(III,:,:),uz4(III,:,:),ax4(III,:,:),...
    az4(III,:,:),z4,pot4(III,:,:),~,~]...
    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t,2,wp,1,1,...
    surface(III,:));%stansberg
end
duration5=toc;
disp(['Duration of second order stansberg calculation = ',...
    num2str(duration5),' seconds']);

%% SPOOL TO EXTREME
%==========================================================================
%IRREGULAR LINEAR WAVE ANALYSIS
%==========================================================================
NI=0;
for spool=[100 200 300 400 500 600 MAXSPOOL];
clear totalSP; clear surfaceSP;
surlin5=zeros(size(surface));total5=surlin5;
ux5=zeros(size(ux2));uz5=ux5;ax5=ux5;az5=ux5;
NI=NI+1;

tic
surfaceSP=linsurface(A,w,phase,0,t,d);
%==========================================================================
%IRREGULAR NON-LINEAR WAVE ANALYSIS
%==========================================================================
dx=10;
[totalSP,~,~,~,~,~,~,~,~,~]...
    =secsurface(A,w,wlim,phase,d,-d,0,nz,t,2,wp,0,0,...
    surfaceSP);%cek surface
[T,SS,~,~]=statwave(t,totalSP);
[~,TS]=sort(SS,'descend');

IT=zeros(1+((spool+AFTER)/(t(2)-t(1))),N);
for INN=1:N
    [~,TT]=find(t==T(TS(INN))-spool);
    IT(:,INN)=TT:TT+((spool+AFTER)/(t(2)-t(1)));
end
IT=unique(IT(:));

surlin5(:,IT)=linsurface(A,w,phase,x,t(IT),d);
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==numel(x)-1
        III=1+(XN-dx):XN+1;
    end
[total5(III,IT),~,ux5(III,IT,:),uz5(III,IT,:),ax5(III,IT,:),az5(III,IT,:),z5,~,~,~]...
    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t(IT),2,wp,1,1,...
    surlin5(III,IT));%stansberg
end
comdurSE(NI)=toc;
disp(['Duration of spool to extreme calculation = ',...
    num2str(comdurSE(NI)),' seconds']);

tic
gridwave(['wavelin5-',num2str(spool)],x,-50:100:50,z5,t,total5,...
    ux5,zeros(size(ux5)),uz5,...
    ax5,zeros(size(ax5)),az5)
duration10=toc;
disp(['Duration of writing spool to extreme gridfile = ',...
    num2str(duration10),' seconds']);

end
save DURATIONSE.mat comdurSE

%% SPOOL+LINEAR TO EXTREME 
%==========================================================================
%IRREGULAR LINEAR WAVE ANALYSIS
%==========================================================================
NI=0;
for spool=[100 200 300 400 500 600 MAXSPOOL];
    NII=0;NI=NI+1;
    for sec=[100 70 50 30 10]%time before second order after the spool finished
clear totalSP; clear surfaceSP;
surlin5=zeros(size(surface));total5=surlin5;
ux5=zeros(size(ux2));uz5=ux5;ax5=ux5;az5=ux5;
NII=NII+1;
tic
surfaceSP=linsurface(A,w,phase,0,t,d);
%==========================================================================
%IRREGULAR NON-LINEAR WAVE ANALYSIS
%==========================================================================
dx=10;
[totalSP,~,~,~,~,~,~,~,~,~]...
    =secsurface(A,w,wlim,phase,d,-d,0,nz,t,2,wp,0,0,...
    surfaceSP);%check surface
[T,SS,~,~]=statwave(t,totalSP);
[~,TS]=sort(SS,'descend'); clear surfaceSP; clear totalSP;

ITL=zeros(1+((spool-sec)/(t(2)-t(1))),N);
ITS=zeros((sec+AFTER)/(t(2)-t(1)),N);
for INN=1:N
    [~,TT]=find(t==T(TS(INN))-spool);
    ITL(:,INN)=TT:(TT+((spool-sec)/(t(2)-t(1))));
    ITS(:,INN)=(TT+((spool-sec)/(t(2)-t(1)))+1):...
        (TT+((spool+AFTER)/(t(2)-t(1))));
end
ITL=unique(ITL(:));ITS=unique(ITS(:));

total5(:,ITL)=linsurface(A,w,phase,x,t(ITL),d);
[ux5(:,ITL,:),uz5(:,ITL,:),ax5(:,ITL,:),az5(:,ITL,:),~,~]=...
    linkinematic(A,w,phase,total5(:,ITL),x,t(ITL),nz,d,2);%stansberg

surlin5(:,ITS)=linsurface(A,w,phase,x,t(ITS),d);
for XN=dx:dx:numel(x)
    III=1+(XN-dx):XN;
    if XN==numel(x)-1
        III=1+(XN-dx):XN+1;
    end
    
[total5(III,ITS),~,ux5(III,ITS,:),uz5(III,ITS,:),ax5(III,ITS,:),...
    az5(III,ITS,:),z5,~,~,~]...
    =secsurface(A,w,wlim,phase,d,-d,x(III),nz,t(ITS),2,wp,1,1,...
    surlin5(III,ITS));%stansberg
end
comdurSLE(NI,NII)=toc;
disp(['Duration of spool+linear to extreme calculation = ',...
    num2str(comdurSLE(NI,NII)),' seconds']);

tic
gridwave(['wavelin5-',num2str(spool),'-',num2str(sec)],x,-50:100:50,z5,t,...
    total5,ux5,zeros(size(ux5)),uz5,ax5,zeros(size(ax5)),az5)
duration10=toc;
disp(['Duration of writing spool+linear to extreme gridfile = ',...
    num2str(duration10),' seconds']);
    end
end
save DURATIONSLE.mat comdurSLE

%%
%==========================================================================
%CREATING GRID WAVE FILE
%==========================================================================
tic
gridwave('wavelin5-R',x,-50:100:50,z1,t,surface,...
    ux3,zeros(size(ux3)),uz3,...
    ax3,zeros(size(ax3)),az3)
duration10=toc;
disp(['Duration of writing linear gridfile = ',...
    num2str(duration10),' seconds']);

tic
gridwave('wavesecwheeler5-R',x,-50:100:50,z2,t,total,...
    ux2,zeros(size(ux2)),uz2,...
    ax2,zeros(size(ax2)),az2)
duration11=toc;
disp(['Duration of writing second order wheeler gridfile = ',...
    num2str(duration11),' seconds']);

tic
gridwave('wavesec5-R',x,-50:100:50,z4,t,total4,...
    ux4,zeros(size(ux4)),uz4,...
    ax4,zeros(size(ax4)),az4)
duration12=toc;
disp(['Duration of writing linear gridfile = ',...
    num2str(duration12),' seconds']);
disp('===================================================================')