function [S,w,m0,m1,m2,m3,m4]=PM(Hs,Tp,wmin,wmax,dw)
%This function is calculated the PM (ISSC) spectrum and its moments
%Hs=significant wave height
%Tp=peak period
%dw=frequency interval, default = 2*pi/10800 (refer to 3 hour simulation)
%wmin=the smallest frequency for spectrum, 
    %default = 2*pi/10800 (refer to 3 hour simulation)
%wmax=the highest frequency for spectrum,default=sqrt(2*g/Hs)
%wmin also could be a set of input frequencies, then wmax and n is
    %neglected
%S=PM spectrum
%w=frequency of each S value
%m0,m1,m2,m3,m4=zeroth,first,second,third and fourth moment of spectrum
    
g=9.812;%gravity acceleration
if ~exist('dw','var'); dw=2*pi/10800; end
if ~exist('wmin','var'); wmin=0.18; end
if ~exist('wmax','var'); wmax=sqrt(2*g/Hs); end    

%option if w already given or not
switch length(wmin)
    case 1
        w=wmin:dw:wmax;
    otherwise
        w=wmin;
        wmean=(w(2:end)-w(1:end-1))/2;
        dw=[(w(2)-w(1)) wmean(1:end-1)+wmean(2:end) w(end)-w(end-1)];
end
wp=2*pi/Tp;
S=Tp*0.05*(Hs^2)*((wp./w).^5).*exp(-5*((wp./w).^4)/4);
S(isnan(S))=0;
m0=sum(S.*dw);
m1=sum(S.*w.*dw);
m2=sum(S.*w.^2.*dw);
m3=sum(S.*w.^3.*dw);
m4=sum(S.*w.^4.*dw);

