function [c,d,lambda,alpha,beta,d1,d2]=cdfHs(SCATTER,Hs,Tp)
%calculation the 3 parameter of 3-parameter weibull 
    %from given scatter diagram:
    
%INPUT :
%SCATTER = scatter diagram
%Hs = set of significant wave from data
%Tp = set of spectral wave period that assigned the significant wave from
    %data
    
%OUTPUT :
%c=parameter used for condition function of the log mean of the spectral peak
    %period
%d=parameter used for condition function of the log variance of the spectral peak
    %period
%lambda = location parameter of 3-parameter weibull distribution
%alpha = scale parameter of 3-parameter weibull distribution
%beta = shape parameter of 3-parameter weibull distribution

Hsmax=ceil(max(Hs));%limit of largest class of Hs
dHs=0.5;%interval of Hs class
Tpmax=ceil(max(Tp));%limit of biggest class of TP
dTp=1;%interval of Tp class

[a,~]=size(SCATTER);%read the number of columns and rows from scatter diagram
Hsn=dHs:dHs:Hsmax;%create number of Hs that represent each Hs class
Tpn=dTp:dTp:Tpmax;
N=sum(sum(SCATTER,1));%calculation the total wave from scatter diagram
Row=sum(SCATTER,2);%sum component of each row

%calculating the CDF from data
FHs=zeros(a,1);
for i=1:a;
    FHs(i)=sum(Row(1:i))/(N+1);
end

%%assigned the graph to 3 parameter weibull
MEAN=mean(Hs);%mean of significant wave height
VARIANCE=var(Hs);%variance of Hs from data
SKEWNESS=(sum(((Hs-MEAN).^3))/N)/(VARIANCE^(3/2));%skewness of Hs from data

%estimating beta from iteration
beta1=0.02;%initial value of beta for iteration
beta2=10;%initial value for iteration
g=0;
while abs(g-SKEWNESS)>0.00000001
    beta=(beta2+beta1)/2;
    g1=(gamma(1+(3/beta1))-(3*gamma(1+(1/beta1))*gamma(1+(2/beta1)))...
        +(2*(gamma(1+(1/beta1))^3)))/...
        ((gamma(1+(2/beta1))-((gamma(1+(1/beta1)))^2))^(3/2));
    
    g=(gamma(1+(3/beta))-(3*gamma(1+(1/beta))*gamma(1+(2/beta)))...
        +(2*(gamma(1+(1/beta))^3)))/...
        ((gamma(1+(2/beta))-((gamma(1+(1/beta)))^2))^(3/2));
    
    if (g-SKEWNESS)*(g1-SKEWNESS)<0
        beta2=beta;
    else
        beta1=beta;
    end
end

%calculate alpha and lambda value
alpha=(VARIANCE/(gamma(1+(2/beta))-((gamma(1+(1/beta)))^2)))^0.5;
lambda=MEAN-(alpha*(gamma(1+(1/beta))));

%plot in weibull paper
figure(1)
scatter(log(Hsn(3:a)-lambda),log(-log(1-FHs(3:a))),'.');
%modifying the axis and label of the graph
x=transpose([Hsn(3:5),Hsn(6:3:10),Hsn(14:7:a)]);
y=transpose([FHs(1),0.06,0.1:0.1:0.9,0.99,0.999,0.9999,0.99999,0.999999]);
set(gca,'XTick',real(log(x-lambda)));
set(gca,'XTickLabel',{num2str(x)});
set(gca,'YTick',log(-log(1-y)));
set(gca,'YTickLabel',{num2str(y)});
grid('on');
xlabel('Significant wave height (Hs)');
ylabel('Cumulative Distribution Function (FHs)');
title('Graph for Hs distribution in weibull paper');
hold all

%plot the fitted distribution function
F=1-exp(-(((Hsn(3:a)-lambda)/alpha).^beta));%3-parameter weibull function
plot(log(Hsn(3:a)-lambda),log(-log(1-F)));
title(['\lambda = ',num2str(lambda)])
hold off

%plot fitted data
figure(2)
scatter(Hsn(Hsn>lambda),FHs(Hsn>lambda),'.');
hold all
clear F
F=1-exp(-(((Hsn(Hsn>lambda)-lambda)/alpha).^beta));
plot(Hsn(Hsn>lambda),F);
xlabel('Significant wave height (Hs)');
ylabel('Cumulative Distribution function (FHs)');
title('Graph for Hs distribution');
title(['\lambda = ',num2str(lambda)])
hold off

%fitting conditional distribution function of Tp
Tpmean=zeros(1,a);Tpvar=Tpmean;
for i=1:a;
    Tpmean1=sum(Tpn.*SCATTER(i,:))/Row(i);
    Tpvar1=sum(((Tpn-Tpmean1).^2).*SCATTER(i,:))/Row(i);
    Tpmean(i)=0.5*log(Tpmean1^4/((Tpmean1^2)+Tpvar1));
    Tpvar(i)=log((Tpvar1/(Tpmean1^2))+1);
end

figure(3)
scatter(Hsn,Tpmean,'.');
xlabel('Hs');
ylabel('Mean of ln(Tp)');
title('mean spectral period vs Hs')
hold all
%fitting mean function
Fmean = @(c,xdata)c(1)+(c(2)*(xdata.^c(3)));
c0 = [1 1 1];%assumed initial
[c] = lsqcurvefit(Fmean,c0,Hsn(~isnan(Tpmean)&Tpmean>0),...
    Tpmean(~isnan(Tpmean)&Tpmean>0));
plot(Hsn,Fmean(c,Hsn))
hold off

figure(4)
scatter(Hsn,Tpvar,'.');
xlabel('Hs');
ylabel('Variance of ln(Tp)');
title('variance of spectral period vs Hs')
hold all
%fitting variance function
Fvar = @(d,xdata)(d(3))+(d(1)*exp(-d(2).*xdata));
d0 = [0 0 0];%assume initial
[d] = lsqcurvefit(Fvar,d0,Hsn(~isnan(Tpvar)&Tpvar>0),Tpvar(~isnan(Tpvar)&Tpvar>0));

if d(3)<0
    clear d
    Fvar = @(d,xdata)(d(1)*exp(-d(2).*xdata));
    [d] = lsqcurvefit(Fvar,[0 0],...
        Hsn(~isnan(Tpvar)&Tpvar>0),Tpvar(~isnan(Tpvar)&Tpvar>0));
    d(3)=0;
end
plot(Hsn,Fvar(d,Hsn));hold all;

Fvar1=@(d,xdata)(d(1)*exp(-d(2).*xdata));
[d1]=lsqcurvefit(Fvar1,[0 0],...
    Hsn(~isnan(Tpvar)&Tpvar>0),Tpvar(~isnan(Tpvar)&Tpvar>0));
plot(Hsn,Fvar1(d1,Hsn));hold all;d1(3)=0;

Fvar2=@(d,xdata)(0.005+d(1)*exp(-d(2).*xdata));
[d2]=lsqcurvefit(Fvar2,[0 0],...
    Hsn(~isnan(Tpvar)&Tpvar>0),Tpvar(~isnan(Tpvar)&Tpvar>0));
plot(Hsn,Fvar2(d2,Hsn));hold all;d2(3)=0.005;

legend('Data',['Treshold = ',num2str(d(3))],...
    'Treshold = 0','Treshold = 0.005')
hold off

figure(5)
plot(exp(Fmean(c,lambda:0.1:20)),lambda:0.1:20,'--','LineWidth',1.5);hold all
plot(exp(norminv(0.05,Fmean(c,lambda:0.1:20),sqrt(Fvar(d,lambda:0.1:20)))),...
    lambda:0.1:20,'--','LineWidth',1.5);hold all
plot(exp(norminv(0.95,Fmean(c,lambda:0.1:20),sqrt(Fvar(d,lambda:0.1:20)))),...
    lambda:0.1:20,'--','LineWidth',1.5);hold all
plot(exp(norminv(0.05,Fmean(c,lambda:0.1:20),sqrt(Fvar1(d1,...
    lambda:0.1:20)))),lambda:0.1:20,'--','LineWidth',1.5);hold all
plot(exp(norminv(0.95,Fmean(c,lambda:0.1:20),sqrt(Fvar1(d1,...
    lambda:0.1:20)))),lambda:0.1:20,'--','LineWidth',1.5);hold all
plot(exp(norminv(0.05,Fmean(c,lambda:0.1:20),sqrt(Fvar2(d2,...
    lambda:0.1:20)))),lambda:0.1:20,'--','LineWidth',1.5);hold all
plot(exp(norminv(0.95,Fmean(c,lambda:0.1:20),sqrt(Fvar2(d2,...
    lambda:0.1:20)))),lambda:0.1:20,'--','LineWidth',1.5);hold all