function gridwave(name,x,y,z,t,elev,vx,vy,vz,ax,ay,az)
%PRINTING RESULT TO GRID WAVE FILE
%THE GRID WAVE FILE FORMAT FOR USFOS IS .w132

fileID = fopen([name,'.w132'],'w');
fprintf(fileID,'''WAVE GRID\r\n''\r\n''\r\n');
fprintf(fileID,' GWF   Type   132   !Grid Wave\r\n''\r\n''\r\n');
fprintf(fileID,'''Mesh Size and Number of Steps\r\n');
fprintf(fileID,...
    '''       Type      Opt   nX      nY      nZ      nStep   iCode (vel,acc,press,elev)\r\n');
fprintf(fileID,' GWF   KeyData   Size   %-7d %-7d %-7d %-7d 1101',...
    numel(x),numel(y),numel(z),numel(t));
fprintf(fileID,'\r\n''\r\n''\r\n''\r\n');
fprintf(fileID,'''Coordinate of Wave Kinematics Point\r\n');
fprintf(fileID,'''      Type  dir   Opt       min     max\r\n');
if numel(x)==1
    fprintf(fileID,' GWF   Grid   X   Constant   %-4.2f   %-4.2f\r\n',...
        min(x)-2,max(x)+2);
else
    fprintf(fileID,' GWF   Grid   X   Constant   %-4.2f   %-4.2f\r\n',...
        x(1)-(x(2)-x(1)),x(end)+(x(2)-x(1)));
end
if numel(y)==1
    fprintf(fileID,' GWF   Grid   Y   Constant   %-4.2f   %-4.2f\r\n',...
        min(y)-2,max(y)+2);
else
    fprintf(fileID,' GWF   Grid   Y   Constant   %-4.2f   %-4.2f\r\n',...
        y(1)-(y(2)-y(1)),y(end)+(y(2)-y(1)));
end
fprintf(fileID,' GWF   Grid   Z   Free\r\n');
fprintf(fileID,'            %-4.2f   %-4.2f   %-4.2f   %-4.2f   %-4.2f\r\n',z);
fprintf(fileID,'''\r\n''\r\n''\r\n''\r\n');

ELEV=repmat(['\r\n',repmat('   %2.3f',[1 numel(y)])],...
    [1 numel(x)]);
KINE=repmat(repmat(repmat('   %2.3f   %2.3f   %2.3f\r\n',...
    [1 numel(z)]),[1 numel(y)]),[1 numel(x)]);
SURFACE=permute(repmat(elev,[1 1 numel(y)]),[3 1 2]);
vx=permute(vx,[3 1 2]);
vy=permute(vy,[3 1 2]);
vz=permute(vz,[3 1 2]);
ax=permute(ax,[3 1 2]);
ay=permute(ay,[3 1 2]);
az=permute(az,[3 1 2]);

for TIME=1:numel(t)
fprintf(fileID,['''TIME\r\n',...
    ' GWF   Time   %-7.2f \r\n''\r\n''\r\n',...
    '''Water Elevation\r\n',...
    ' GWF   Elevation\r\n''','\r\n',ELEV,'\r\n''\r\n''\r\n''\r\n',...
    '''Horizontal Velocity\r\n',...
    ' GWF   Velocity\r\n',...
    '''    vx      vy      vz       Point\r\n',...
    KINE,'''\r\n''\r\n''Horizontal Acceleration\r\n',...
    ' GWF   Acceleration\r\n',...
    '''    ax      ay      az       Point\r\n',KINE,...
    '''\r\n''\r\n''\r\n''\r\n'],t(TIME),SURFACE(:,:,TIME),...
    repmat([permute(vx(:,:,TIME),[3,1,2]);...
    permute(vy(:,:,TIME),[3 1 2]);permute(vz(:,:,TIME),[3 1 2])],...
    [1 numel(y)]),repmat([permute(ax(:,:,TIME),[3,1,2]);...
    permute(ay(:,:,TIME),[3 1 2]);permute(az(:,:,TIME),[3 1 2])],...
    [1 numel(y)]));
end
fprintf(fileID,'''\r\n''\r\n''\r\n''\r\n');
fprintf(fileID,' GWF    END');
fprintf(fileID,'\r\n''----END OF FILE----');

fclose(fileID);

