close all
clear all
clc

%================================INPUT==============================
DATA='DATANEW.dat'; %input the hindcast file name
depth=100;%m;it is the depth used for calculating the wave crest
%=============================ENDOFINPUT===========================

%-------------------------START OF CALCULATION----------------------

[Hs,tp,Tp]=HsTp(DATA);
SCATTER=scatdiag(Hs,Tp);%SCATTER= scatter diagram of Hs and Tp

%checking if the amount of data is matched between hindcast and scatter data
row=size(Hs,1);
check=sum(sum(SCATTER,1))-size(Hs,1);

figure(5)
plot(Tp,Hs,'.cy');hold all;
%Fitting distribution function for Hs and Tp|Hs
[c,d,lambda,alpha,beta,d1,d2]=cdfHs(SCATTER,Hs,Tp);
%c = set of parameter used for log mean spectral period as function %of Hs
%d = set of parameter used for log variance spectral period as %function of Hs
%lambda,alpha,beta = location,scale and shape parameter of 3-%parameterWeibull
%calculating the Hs for q=10-1,10-2,10-4 and associated spectral %period with certain band

[Hs10,Tpm10,Tplow10,Tphigh10]=qprob(0.1,c,d,lambda,alpha,beta);
[Hs100,Tpm100,Tplow100,Tphigh100]=qprob(0.01,c,d,lambda,alpha,beta);
[Hs10000,Tpm10000,Tplow10000,Tphigh10000]=qprob(0.0001,c,d,lambda,alpha,beta);

%calculating the q probability for Hs and Tp, create the contour %line,
%do the long term analysis to get extreme individual wave height and
%3 hour extreme wave height also extreme individual wave crest and
%3 hour wave crest using forristal ditribution function then %determine
%the percentile for shorterm distribution based on worst sea state
d(2)
q=[0.1,0.01,0.0001];
for z=1:3;
    figure(5);hold all
[Poutside(z,1),COUNT(z,1),seastate{z}]=...
    contourg(Hs,Tp,q(z),c,d,lambda,alpha,beta);
[n(z),m(z),h(z),C(z),FHex(z),FCex(z),V(z),P(z),VP(z)]=HCin(q(z),depth,c,d,lambda,alpha,beta);
[n3(z),m3(z),h3(z),C3(z),FHex3(z),FCex3(z),P3(z)]=HC3H(q(z),depth,c,d,lambda,alpha,beta);
[n20(z),m20(z),h20(z),C20(z),FHex20(z),FCex20(z),P3(z)]=HC20M(q(z),depth,c,d,lambda,alpha,beta);
[percentile(z,:),worst1(z,:),worst2(z,:),~,~]=perex(depth,seastate{z},C3(z),h3(z));
end

%Poutside=probability of point located outside contour line
%COUNT=countint point outside contour line
%q=anual probability
%n and m just a number to make sure the iteration for wave height %and wave crest did noot exceed acceptable value (when m or n reach %50, theresult is not acceptable)
%h;FHex=extreme individual wave height; and it's probabilty (just %forchecking purpose)
%c;FCex=extreme individual wavev crest; and it's probabilty (just %forchecking purpose)
%h3;FHex3=3 hour extreme wave heightt; and it's probabilty (just for
%checking purpose)
%c3;FCex3=3 hour extreme wave crestt; and it's probabilty (just for
%checking purpose)
%===================================================================
figure(5)
xlabel('Tp');
ylabel('Hs');
legend('DATA',['Mean; Treshold = ',num2str(c(3))],...
    ['5%; Treshold = ',num2str(c(3))],['95%;Treshold = ',num2str(c(3))],...
    '5%; Treshold = 0','95%; Treshold = 0','5%; Treshold = 0.005',...
    '95%; Treshold = 0.005','q = 0.1 per year','q = 0.01 per year',...
    'q = 0.0001 per year','Location','NorthWest');

%WAVE BREAKING
L=2*pi./wavenum(0:25,depth);
HH=0.14*tanh(2*pi*depth./L).*L;
%figure(5)
%plot(0:25,HH);

%number outside boundary
OUTSIDE=round(Poutside*row);

%===================================================================
%PRINTING THE RESULT
fileID = fopen('Result.txt','w');
fprintf(fileID,'                                                      RESULT\r\n');
fprintf(fileID,'=================================================');
fprintf(fileID,'=============================================\r\n');
fprintf(fileID,'Number of data = %10.0f\r\n',size(Hs,1));
fprintf(fileID,'Water depth = %10.2f m\r\n',depth);
fprintf(fileID,'Q-PROBABILITY VALUE (Hs and Tp worst is the considered worst seastate on the contour line)\r\n');
fprintf(fileID,'%12s %10s %10s %10s %10s %10s %10s %10s %10s\r\n',...
'','Hs','Tp mean','Tp 5%','Tp 95%','HsWorst(H)','TpWorst(H)','HsWorst(C)','TpWorst(C)');
fprintf(fileID,'%12s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s \r\n',...
'10 year',Hs10,Tpm10,Tplow10,Tphigh10,worst1(1,:),worst2(1,:));
fprintf(fileID,'%12s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s \r\n',...
'100 year',Hs100,Tpm100,Tplow100,Tphigh100,worst1(2,:),worst2(2,:));
fprintf(fileID,'%12s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s %10.2s \r\n',...
'10000 year',Hs10000,Tpm10000,Tplow10000,Tphigh10000,worst1(3,:),worst2(3,:));

fprintf(fileID,'\r\n%12s %28s %24s %28s %24s \r\n',...
'','Height extreme (individual)',...
'Height extreme (3-hour)','Crest extreme (individual)',...
'Crest extreme (3-hour)');
fprintf(fileID,'%12s %28.2s %24.2s %28.2s %24.2s \r\n',...
'10 year',h(1),h3(1),C(1),C3(1));
fprintf(fileID,'%12s %28.2s %24.2s %28.2s %24.2s \r\n',...
'100 year',h(2),h3(2),C(2),C3(2));
fprintf(fileID,'%12s %28.2s %24.2s %28.2s %24.2s \r\n',...
'10000 year',h(3),h3(3),C(3),C3(3));

fprintf(fileID,'\r\n%12s %16s %16s %10s %26s %14s \r\n',...
'','percentile (H)','percentile (C)','Poutside','Data outside from prob','Data outside');
fprintf(fileID,'%12s %16.2s %16.2s %10.2s %26.0f %14.0f \r\n',...
'10 year',percentile(1,:),Poutside(1),OUTSIDE(1),COUNT(1));
fprintf(fileID,'%12s %16.2s %16.2s %10.2s %26.0f %14.0f \r\n',...
'100 year',percentile(2,:),Poutside(2),OUTSIDE(2),COUNT(2));
fprintf(fileID,'%12s %16.2s %16.2s %10.2s %26.0f %14.0f \r\n',...
'10000 year',percentile(3,:),Poutside(3),OUTSIDE(3),COUNT(3));

fprintf(fileID,'\r\n\nParameters of 3-parameter Weibull\r\n');
fprintf(fileID,'location parameter (lambda) = %4.2f \r\n',lambda);
fprintf(fileID,'scale parameter (alpha) = %4.2f \r\n',alpha);
fprintf(fileID,'shape parameter (beta) = %4.2f \r\n',beta);
fprintf(fileID,'\r\nParameters of conditional log mean spectral peak period\r\n');
fprintf(fileID,'c(1)+(c(2)*(Hs.^c(3))):\r\n c(1)=%4.2f\r\n c(2)=%4.2f\r\n c(3)=%4.2f\r\n',c);
fprintf(fileID,'\r\nParameters of conditional log variance spectral peak period\r\n');
fprintf(fileID,'d(3))+(d(1)*exp(-d(2).*Hs):\r\n d(1)=%4.2f\r\n d(2)=%4.2f\r\n d(3)=%4.2f\r\n',d);
fclose(fileID);
type Result.txt

%==========================================================================
%PRINTING THE RESULT
[~,~,~,CCon,Hcon]=perex(depth,seastate{2}(seastate{2}(:,1)>12,:),C3(2),h3(2));
Tcon=0.9*seastate{2}(seastate{2}(:,1)>12,2);
figure(100)
hold all
plot(seastate{2}(:,2),seastate{2}(:,1),'.-')
plot(seastate{2}(seastate{2}(:,1)>12,2),seastate{2}(seastate{2}(:,1)>12,1),'.-')

pause(5)

HFITcon=zeros(size(Hcon));
for i=1:length(Tcon);
    HFITcon(i)=fiitingstokes(Hcon(i),CCon(i),Tcon(i),depth);
end
    
fileID = fopen('HSTPCONHT.txt','w');
fprintf(fileID,'H     T\n');
fprintf(fileID,'%2.2f %2.2f \n',[Hcon';Tcon']);
type HSTPCONHT.txt

fileID = fopen('HSTPCONCT.txt','w');
fprintf(fileID,'H     T\n');
fprintf(fileID,'%2.2f %2.2f \n',[HFITcon';Tcon']);
type HSTPCONCT.txt

save HSTPCON.mat seastate