function [Hs,Tpmean,Tplow,Tphigh]=qprob(q,c,d,lambda,alpha,beta)
%calculating the q-probabolity value for significant wave height and its
    %certain band spectral peak period
%INPUT:
%q=annual probability
%band=the band of spectral peak period for calculated Hs
%c=parameter used for condition function of the log mean of the spectral peak
    %period
%d=parameter used for condition function of the log variance of the spectral peak
    %period
%lambda = location parameter of 3-parameter weibull distribution
%alpha = scale parameter of 3-parameter weibull distribution
%beta = shape parameter of 3-parameter weibull distribution

%OUTPUT:
%Hs=the q-probability value of significant wave height
%t=certain band of spectral peak period for the calculated Hs


%calclating the CDF for q-anual period
N=q/2920;FHs=1-N;
Hs=(((-log(1-FHs))^(1/beta))*alpha)+lambda;
Tpm=c(1)+(c(2)*(Hs^c(3)));
Tpv=(d(3))+(d(1)*exp(-d(2)*Hs));
Tpmean=exp(Tpm+(0.5*Tpv));
Tplow=exp(norminv(0.05,Tpm,sqrt(Tpv)));
Tphigh=exp(norminv(0.95,Tpm,sqrt(Tpv)));
