function [ux2,uz2,ax2,az2,z,pot2]=...
    seckinemtic(A,AA,w,k,phase,surface,Dmin,Dplus,...
    Kmin,Kplus,Wmin,Wplus,x,nz,t,d,lower,method,wp,WW,PSImin,PSIplus,plo)
%Calculating the second order correction. Have to run secsurface first to
%get the input.
%A=AixAj = multiplication of amplitudes i and j from spectrum 
    %linearization(use secsurface function)
%w=wave frequency
%surface=second order surface(use secsurface)
%Dmin,Dplus,kmin,kplus,PSImin,PSIplus are input from secsurface calculation
%x=coordinate
%nz= number of z coordinate
%t=time
%d=depth
%method=method of calculating kinematic for z>0:
    %1.Wheeler Stretching
    %2.Stansberg Linear Extrapolation
    
if ~exist('method','var'); method=1; end
if ~exist('d','var'); d=1000; end
if ~exist('x','var'); x=0; end
if ~exist('t','var'); t=0; end
if ~exist('nz','var'); nz=50; end
if ~exist('plo','var'); plo=0; end

%concentrate the points near the surface
%nsurf=round(0.75*nz);
%nrest=nz-nsurf;


z=[-d -80 -70 -60:5:-30 -29:30];

pot2=zeros(length(x),length(t),length(z));
ux2=zeros(length(x),length(t),length(z));
uz2=zeros(length(x),length(t),length(z));
ax2=zeros(length(x),length(t),length(z));
az2=zeros(length(x),length(t),length(z));
UX2mins=ux2;UX2pluss=ux2;UXder=ux2;
AX2mins=ax2;AX2pluss=ax2;AXder=ax2;
%interpret second order surface by built in fft function for wheeler method
if numel(t)==1
    disp('input more time point, iteration cannot be done by single time value');
end

switch method
    case 1
        lenz=length(z);lent=length(t);
        N = 2^nextpow2(size(surface,2));
        faxis = linspace(0,1/(2*(t(end)-t(end-1))),N/2+1);
        W1=2*pi*faxis(2:end-1);
        
        %FREQUENCY CUT
        W=W1(W1<=4*wp);
        K=wavenum(W,d);
        for ix=1:length(x)
            Y = fft(surface(ix,:),N)/N;
            AFFT1 = 2*abs(Y(2:N/2));
            PHASE1 = -unwrap(angle(Y(2:N/2)));
                       
            %FREQUENCY CUT
            AFFT=AFFT1(W1<=4*wp);
            PHASE=PHASE1(W1<=4*wp);
            
            parfor it=1:lent
                for iz=1:lenz
                    if z(iz)>surface(ix,it)
                        pot2(ix,it,iz)=0;
                        ux2(ix,it,iz)=0;
                        uz2(ix,it,iz)=0;
                        ax2(ix,it,iz)=0;
                        az2(ix,it,iz)=0;
                    else                        
                    [pot2(ix,it,iz),ux2(ix,it,iz),uz2(ix,it,iz),...
                        ax2(ix,it,iz),az2(ix,it,iz)]=...
                        wheeler(AFFT,K,W,PHASE,surface(ix,it),...
                        x(ix),z(iz),t(it),d);
                    end
                end
            end
        end
        
    case 2
        g=9.812;%gravity acceleration

        pota=g*A./(w.*cosh(k*d));
        ua=g*k.*A./(w.*cosh(k*d));
        aa=g*k.*A./cosh(k*d);

        %correction
        AMIN=0.25*(g^2*AA./WW).*(Dmin./Wmin)./...
            cosh(abs(Kmin)*d);%amplitude of different frequency
        APLUS=0.25*(g^2*AA./WW).*(Dplus./Wplus)./...
            cosh(Kplus*d);%Amplitude of sum frequency
        UXAMIN=AMIN.*Kmin;UXAPLUS=APLUS.*Kplus;
        UZAMIN=AMIN.*abs(Kmin);UZAPLUS=APLUS.*Kplus;
        AXAMIN=UXAMIN.*Wmin;AXAPLUS=UXAPLUS.*Wplus;
        AZAMIN=UZAMIN.*Wmin;AZAPLUS=UZAPLUS.*Wplus;
        
        UXderA=g*k.^2.*A.*sinh(k*(d+0))./(w.*cosh(k*d));
        AXderA=g*k.^2.*A.*sinh(k*(d+0))./cosh(k*d);
        POTderA=(g*k.*A./w).*sinh(k*(0+d))./cosh(k*d);
        UZderA=(g*k.*A./w)./cosh(k*d);
        AZderA=g*k.*A./cosh(k*d);
        
        %Vectorization for efficient and faster calculation
        lenz=[1 1 length(z)];
        Z=repmat(permute((min(z,0)+d),[1 3 2]),[size(WW) 1]);
        KPLUS=repmat(Kplus,lenz);
        KAMIN=repmat(abs(Kmin),lenz);
        
        AMINI=repmat(AMIN,lenz).*cosh(KAMIN.*Z);
        APLUSI=repmat(APLUS,lenz).*cosh(KPLUS.*Z);
        UXAMINI=repmat(UXAMIN,lenz).*cosh(KAMIN.*Z);
        UXAPLUSI=repmat(UXAPLUS,lenz).*cosh(KPLUS.*Z);
        UZAMINI=repmat(UZAMIN,lenz).*sinh(KAMIN.*Z);
        UZAPLUSI=repmat(UZAPLUS,lenz).*sinh(KPLUS.*Z);
        AXAMINI=repmat(AXAMIN,lenz).*cosh(KAMIN.*Z);
        AXAPLUSI=repmat(AXAPLUS,lenz).*cosh(KPLUS.*Z);
        AZAMINI=repmat(AZAMIN,lenz).*sinh(KAMIN.*Z);
        AZAPLUSI=repmat(AZAPLUS,lenz).*sinh(KPLUS.*Z);
        
        K=repmat(k,lenz);W=repmat(w,lenz);PHASE=repmat(phase,lenz);
        ZK=repmat(permute((d+min(z,0)),[1 3 2]),[size(k) 1]);
        
        potai=repmat(pota,lenz).*cosh(K.*ZK);
        uxa=repmat(ua,lenz).*cosh(K.*ZK);
        uza=repmat(ua,lenz).*sinh(K.*ZK);
        axa=repmat(aa,lenz).*cosh(K.*ZK);
        aza=repmat(aa,lenz).*sinh(K.*ZK);
        
        ZD=repmat(permute(max(z,0),[1 3 2]),[size(k) 1]);
        SCALEZ=repmat(permute(max(z,0)./z,[1 3 2]),[size(k) 1]);
        UXderAI=repmat(UXderA,lenz).*ZD;
        AXderAI=repmat(AXderA,lenz).*ZD;
        POTderAI=repmat(POTderA,lenz).*ZD;
        UZderAI=repmat(UZderA,lenz).*...
            ((repmat(sinh(k*(0+d)),lenz).*SCALEZ)+...
            (ZD.*repmat(k.*cosh(k*(0+d)),lenz)));
        AZderAI=repmat(AZderA,lenz).*...
            ((repmat(sinh(k*(0+d)),lenz).*SCALEZ)+...
            (ZD.*repmat(k.*cosh(k*(0+d)),lenz)));
                      
        lenx=length(x);lent=length(t);
            parfor it=1:lent
                for ix=1:lenx
                    PSIMIN=PSImin(:,:,ix,it);
                    PSIMIN=repmat(PSIMIN,lenz);
                    
                    PSIPLUS=PSIplus(:,:,ix,it);
                    PSIPLUS=repmat(PSIPLUS,lenz);
                    
                    [pot2(ix,it,:),ux2(ix,it,:),uz2(ix,it,:),...
                        ax2(ix,it,:),az2(ix,it,:),UX2mins(ix,it,:),...
                        UX2pluss(ix,it,:),UXder(ix,it,:),...
                        AX2mins(ix,it,:),AX2pluss(ix,it,:),...
                        AXder(ix,it,:)]=...
                        secstansberg(K,W,PHASE,x(ix),t(it),...
                        PSIMIN,PSIPLUS,AMINI,APLUSI,UXAMINI,UXAPLUSI,...
                        UZAMINI,UZAPLUSI,AXAMINI,AXAPLUSI,AZAMINI,AZAPLUSI,...
                        potai,uxa,uza,axa,aza,...
                        UXderAI,AXderAI,POTderAI,UZderAI,AZderAI);
                end
            end
            
            %showing value only for z below water surface elevation
            Zz=repmat(permute(z,[1 3 2]),[length(x) length(t) 1]);
            activate=Zz<=repmat(surface,[1 1 length(z)]);
            pot2=pot2.*activate;
            ux2=ux2.*activate;
            uz2=uz2.*activate;
            ax2=ax2.*activate;
            az2=az2.*activate;
            UX2mins=UX2mins.*activate;
            UX2pluss=UX2pluss.*activate;
            UXder=UXder.*activate;
            %UX2min2(ix,it,iz)=0;
            %UX2plus2(ix,it,iz)=0;
            AX2mins=AX2mins.*activate;
            AX2pluss=AX2pluss.*activate;
            AXder=AXder.*activate;
            %AX2min2(ix,it,iz)=0;
            %AX2plus2(ix,it,iz)=0;
        
        if plo==1 && max(x==0)>0
            
        [~,cp]=max(surfacekin(ux2(x==0,:,:)));
        %axe1=z(x==0,cp,:);
        axe2=UX2mins(x==0,cp,:);axe2=axe2(:);
        axe3=UX2pluss(x==0,cp,:);axe3=axe3(:);
        axe4=UXder(x==0,cp,:);axe4=axe4(:);
        %axe5=UX2min2(x==0,cp,:);axe5=axe5(:);
        %axe6=UX2plus2(x==0,cp,:);axe6=axe6(:);
        figure(4)
        plot(...%axe5(~~axe5),z(~~axe5),'--',...
            ...%axe6(~~axe6),z(~~axe6),'--',...
            axe4(z<surface(x==0,cp)),...
            z(z<surface(x==0,cp)),'-x',...
            axe2(~~axe2),z(~~axe2),'-x',...
            axe3(~~axe3),z(~~axe3),'-x');hold all
        
        [~,ci]=max(surfacekin(ax2(x==0,:,:)));
        %axee1=z(x==0,ci,:);
        axee2=AX2mins(x==0,ci,:);axee2=axee2(:);
        axee3=AX2pluss(x==0,ci,:);axee3=axee3(:);
        axee4=AXder(x==0,ci,:);axee4=axee4(:);
        %axee5=AX2min2(x==0,ci,:);axee5=axee5(:);
        %axee6=AX2plus2(x==0,ci,:);axee6=axee6(:);
        figure(5)
        plot(...%axee5(~~axee5),z(~~axee5),'--',...
            ...%axee6(~~axee6),z(~~axee6),'--',...
            axee4(z<surface(x==0,ci)),...
            z(z<surface(x==0,ci)),'-x',...
            axee2(~~axee2),z(~~axee2),'-x',...
            axee3(~~axee3),z(~~axee3),'-x');hold all
        end
end
uz2(isnan(uz2))=0;
az2(isnan(az2))=0;