function [pot,ux,uz,ax,az,p]=wheeler(A,k,w,phase,surface,x,z,t,d)
%Using Wheeler streching method to calculate kinematic;
%A=wave amplitude
%k=wave number
%w=frequency of each
%surface=wave surface
%d=water depth
%x=x coordinate
%z=vertical coordinate
%t=time
%u=water particle velocity, column 1=x, column 2=z
%a=wave particle acceleration, column 1=x, column 2=z
%p=pressure

g=9.812;%gravity acceleration
rho=1025;%density of seawater

pota=g*A./(w.*cosh(k*d));
ua=g*k.*A./(w.*cosh(k*d));
aa=g*k.*A./cosh(k*d);
pa=rho*g*A./cosh(k*d);

znew=(z-surface)./(1+surface/d);

%potensial velocity
pot=sum(pota.*cosh(k.*(znew+d)).*sin(k*x-w*t+phase));
            
%particle velocity
ux=sum(ua.*cosh(k*(d+znew)).*cos(k*x-w*t+phase));
uz=sum(ua.*sinh(k*(d+znew)).*sin(k*x-w*t+phase));
            
%particle acceleration
ax=sum(aa.*cosh(k*(d+znew)).*sin(k*x-w*t+phase));
az=-sum(aa.*sinh(k*(d+znew)).*cos(k*x-w*t+phase));
            
%pressure
p=sum(pa.*cosh(k*(d+znew)).*cos(k*x-w*t+phase));